==> marketing-api-java-sdk-1.1.4-sources.jar: com/tencent/ads/examples/BasicOperations/BusinessAssets/AddProductCatalogs.java <==
package com.tencent.ads.examples.BasicOperations.BusinessAssets;

import com.tencent.ads.ApiContextConfig;
import com.tencent.ads.TencentAds;
import com.tencent.ads.exception.TencentAdsResponseException;
import com.tencent.ads.exception.TencentAdsSDKException;
import com.tencent.ads.model.*;
import com.tencent.ads.model.ProductCatalogsAddRequest;

public class AddProductCatalogs {
  /** YOUR ACCESS TOKEN */
  public String ACCESS_TOKEN = "YOUR ACCESS TOKEN";

  /** TencentAds */
  public TencentAds tencentAds;

  public String catalogName = "SDK商品库5ede252bae6f6";
  public ProductCatalogsAddRequest data = new ProductCatalogsAddRequest();
  public Long accountId = null;
  public CatalogType catalogType = CatalogType.CATALOG_TYPE_STANDARD;
  public CatalogIndustry industryType = CatalogIndustry.INDUSTRY_TYPE_ECOMMERCE;
  public CatalogScale catalogScaleType = CatalogScale.NORMAL;

  public void init() {
    this.tencentAds = TencentAds.getInstance();
    this.tencentAds.init(
        new ApiContextConfig().accessToken(ACCESS_TOKEN).isDebug(true)); // debug==true 会打印请求详细信息
    this.tencentAds.useSandbox(); // 默认使用沙箱环境，如果要请求线上，这里需要设为线上环境
    this.buildParams();
  }

  public void buildParams() {
    data.setCatalogName(catalogName);

    data.setAccountId(accountId);

    data.setCatalogType(catalogType);

    data.setIndustryType(industryType);

    data.setCatalogScaleType(catalogScaleType);
  }

  public ProductCatalogsAddResponseData addProductCatalogs() throws Exception {
    ProductCatalogsAddResponseData response = tencentAds.productCatalogs().productCatalogsAdd(data);
    return response;
  }

  public static void main(String[] args) {
    try {
      AddProductCatalogs addProductCatalogs = new AddProductCatalogs();
      addProductCatalogs.init();
      ProductCatalogsAddResponseData response = addProductCatalogs.addProductCatalogs();
    } catch (TencentAdsResponseException e) {
      e.printStackTrace();
    } catch (TencentAdsSDKException e) {
      e.printStackTrace();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}

==> marketing-api-java-sdk-1.1.52-sources.jar: com/tencent/ads/examples/BasicOperations/BusinessAssets/AddProductCatalogs.java <==
package com.tencent.ads.examples.BasicOperations.BusinessAssets;

import com.tencent.ads.ApiContextConfig;
import com.tencent.ads.TencentAds;
import com.tencent.ads.exception.TencentAdsResponseException;
import com.tencent.ads.exception.TencentAdsSDKException;
import com.tencent.ads.model.*;
import com.tencent.ads.model.ProductCatalogsAddRequest;

public class AddProductCatalogs {
  /** YOUR ACCESS TOKEN */
  public String ACCESS_TOKEN = "YOUR ACCESS TOKEN";

  /** TencentAds */
  public TencentAds tencentAds;

  public String catalogName = "SDK商品库5ede252bae6f6";
  public ProductCatalogsAddRequest data = new ProductCatalogsAddRequest();
  public Long accountId = null;
  public CatalogType catalogType = CatalogType.CATALOG_TYPE_STANDARD;
  public CatalogIndustry industryType = CatalogIndustry.ECOMMERCE;
  public CatalogScale catalogScaleType = CatalogScale.NORMAL;

  public void init() {
    this.tencentAds = TencentAds.getInstance();
    this.tencentAds.init(
        new ApiContextConfig().accessToken(ACCESS_TOKEN).isDebug(true)); // debug==true 会打印请求详细信息
    this.tencentAds.useSandbox(); // 默认使用沙箱环境，如果要请求线上，这里需要设为线上环境
    this.buildParams();
  }

  public void buildParams() {
    data.setCatalogName(catalogName);

    data.setAccountId(accountId);

    data.setCatalogType(catalogType);

    data.setIndustryType(industryType);

    data.setCatalogScaleType(catalogScaleType);
  }

  public ProductCatalogsAddResponseData addProductCatalogs() throws Exception {
    ProductCatalogsAddResponseData response = tencentAds.productCatalogs().productCatalogsAdd(data);
    return response;
  }

  public static void main(String[] args) {
    try {
      AddProductCatalogs addProductCatalogs = new AddProductCatalogs();
      addProductCatalogs.init();
      ProductCatalogsAddResponseData response = addProductCatalogs.addProductCatalogs();
    } catch (TencentAdsResponseException e) {
      e.printStackTrace();
    } catch (TencentAdsSDKException e) {
      e.printStackTrace();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}
